@@ -25,6 +25,14 @@ import time
 from collections.abc import Sequence
 from typing import TYPE_CHECKING, Any
 
+from google.api_core.exceptions import NotFound
+from google.api_core.gapic_v1.method import DEFAULT, _MethodDefault
+from google.auth.transport import requests as google_requests
+
+# not sure why but mypy complains on missing `container_v1` but it is clearly there and is importable
+from google.cloud import exceptions  # type: ignore[attr-defined]
+from google.cloud.container_v1 import ClusterManagerAsyncClient, ClusterManagerClient
+from google.cloud.container_v1.types import Cluster, Operation
 from kubernetes import client
 from kubernetes_asyncio import client as async_client
 from kubernetes_asyncio.config.kube_config import FileOrData
@@ -39,14 +47,6 @@ from airflow.providers.google.common.hooks.base_google import (
     GoogleBaseAsyncHook,
     GoogleBaseHook,
 )
-from google.api_core.exceptions import NotFound
-from google.api_core.gapic_v1.method import DEFAULT, _MethodDefault
-from google.auth.transport import requests as google_requests
-
-# not sure why but mypy complains on missing `container_v1` but it is clearly there and is importable
-from google.cloud import exceptions  # type: ignore[attr-defined]
-from google.cloud.container_v1 import ClusterManagerAsyncClient, ClusterManagerClient
-from google.cloud.container_v1.types import Cluster, Operation
 
 if TYPE_CHECKING:
     import google.auth.credentials
@@ -64,11 +64,13 @@ class GKEClusterConnection:
         ssl_ca_cert: str,
         credentials: google.auth.credentials.Credentials,
         enable_tcp_keepalive: bool = False,
+        use_dns_endpoint: bool = False,
     ):
         self._cluster_url = cluster_url
         self._ssl_ca_cert = ssl_ca_cert
         self._credentials = credentials
         self.enable_tcp_keepalive = enable_tcp_keepalive
+        self.use_dns_endpoint = use_dns_endpoint
 
     def get_conn(self) -> client.ApiClient:
         configuration = self._get_config()
@@ -86,12 +88,13 @@ class GKEClusterConnection:
             api_key_prefix={"authorization": "Bearer"},
             api_key={"authorization": self._get_token(self._credentials)},
         )
-        configuration.ssl_ca_cert = FileOrData(
-            {
-                "certificate-authority-data": self._ssl_ca_cert,
-            },
-            file_key_name="certificate-authority",
-        ).as_file()
+        if not self.use_dns_endpoint:
+            configuration.ssl_ca_cert = FileOrData(
+                {
+                    "certificate-authority-data": self._ssl_ca_cert,
+                },
+                file_key_name="certificate-authority",
+            ).as_file()
         return configuration
 
     @staticmethod
@@ -417,6 +420,7 @@ class GKEKubernetesHook(GoogleBaseHook, KubernetesHook):
         cluster_url: str,
         ssl_ca_cert: str,
         enable_tcp_keepalive: bool = False,
+        use_dns_endpoint: bool = False,
         *args,
         **kwargs,
     ):
@@ -424,6 +428,7 @@ class GKEKubernetesHook(GoogleBaseHook, KubernetesHook):
         self._cluster_url = cluster_url
         self._ssl_ca_cert = ssl_ca_cert
         self.enable_tcp_keepalive = enable_tcp_keepalive
+        self.use_dns_endpoint = use_dns_endpoint
 
     def get_conn(self) -> client.ApiClient:
         return GKEClusterConnection(
@@ -431,6 +436,7 @@ class GKEKubernetesHook(GoogleBaseHook, KubernetesHook):
             ssl_ca_cert=self._ssl_ca_cert,
             credentials=self.get_credentials(),
             enable_tcp_keepalive=self.enable_tcp_keepalive,
+            use_dns_endpoint=self.use_dns_endpoint,
         ).get_conn()
 
     def apply_from_yaml_file(
